@@ -1,6 +1,6 @@
 import sys, getopt
 # from file_upload.file_client import main
-from file_client import main
+from file_upload.file_client import main
 
 
 def start():
